@@ -37,7 +37,6 @@
 #define GTHUMB_STOCK_EDIT_IMAGE           "gthumb-edit-image"
 #define GTHUMB_STOCK_FILM                 "gthumb-film"
 #define GTHUMB_STOCK_FLIP                 "gthumb-flip"
-#define GTHUMB_STOCK_FULLSCREEN           "gthumb-fullscreen"
 #define GTHUMB_STOCK_HISTOGRAM            "gthumb-histogram"
 #define GTHUMB_STOCK_HUE_SATURATION       "gthumb-hue-saturation"
 #define GTHUMB_STOCK_IMAGE                "gthumb-image"
@@ -46,7 +45,6 @@
 #define GTHUMB_STOCK_LEVELS               "gthumb-levels"
 #define GTHUMB_STOCK_MIRROR               "gthumb-mirror"
 #define GTHUMB_STOCK_NEXT_IMAGE           "gthumb-next-image"
-#define GTHUMB_STOCK_NORMAL_VIEW          "gthumb-normal-view"
 #define GTHUMB_STOCK_POSTERIZE            "gthumb-posterize"
 #define GTHUMB_STOCK_PREVIOUS_IMAGE       "gthumb-previous-image"
 #define GTHUMB_STOCK_REDUCE_COLORS        "gthumb-reduce-colors"
