@@ -32,6 +32,7 @@
 #include <libgnomevfs/gnome-vfs-uri.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
 
+#include "gth-iviewer.h"
 #include "image-viewer.h"
 #include "cursors.h"
 #include "pixbuf-utils.h"
@@ -57,7 +58,6 @@ enum {
 	CLICKED,
 	IMAGE_LOADED,
 	ZOOM_CHANGED,
-	SIZE_CHANGED,
 	REPAINTED,
 	SCROLL,
 	LAST_SIGNAL
@@ -163,15 +163,6 @@ image_viewer_class_init (ImageViewerClass *class)
 			      gthumb_marshal_VOID__VOID,
 			      G_TYPE_NONE, 
 			      0);
-	image_viewer_signals[SIZE_CHANGED] =
-		g_signal_new ("size_changed",
-			      G_TYPE_FROM_CLASS (class),
-			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (ImageViewerClass, size_changed),
-			      NULL, NULL,
-			      gthumb_marshal_VOID__VOID,
-			      G_TYPE_NONE, 
-			      0);
 	image_viewer_signals[REPAINTED] =
 		g_signal_new ("repainted",
 			      G_TYPE_FROM_CLASS (class),
@@ -391,14 +382,6 @@ image_viewer_init (ImageViewer *viewer)
 			  "value_changed",
 			  G_CALLBACK (vadj_value_changed), 
 			  viewer);
-
-	gtk_widget_set_events (GTK_WIDGET (viewer), 
-			       GDK_EXPOSURE_MASK | 
-			       GDK_BUTTON_PRESS_MASK |
-			       GDK_BUTTON_RELEASE_MASK |
-			       GDK_POINTER_MOTION_MASK |
-			       GDK_POINTER_MOTION_HINT_MASK |
-			       GDK_BUTTON_MOTION_MASK);
 }
 
 
@@ -1183,7 +1166,13 @@ image_viewer_realize (GtkWidget *widget)
 	attributes.visual      = gtk_widget_get_visual (widget);
 	attributes.colormap    = gtk_widget_get_colormap (widget);
 	attributes.event_mask  = (gtk_widget_get_events (widget) 
-				  | GDK_EXPOSURE_MASK);
+				  | GDK_EXPOSURE_MASK
+				  | GDK_BUTTON_PRESS_MASK 
+				  | GDK_BUTTON_RELEASE_MASK 
+				  | GDK_POINTER_MOTION_MASK 
+				  | GDK_POINTER_MOTION_HINT_MASK 
+				  | GDK_BUTTON_MOTION_MASK);
+
 	attributes_mask        = (GDK_WA_X 
 				  | GDK_WA_Y 
 				  | GDK_WA_VISUAL 
@@ -1335,9 +1324,7 @@ image_viewer_size_allocate (GtkWidget       *widget,
 			viewer->y_offset = 0;
 
 		if ((width != viewer->hadj->upper) || (height != viewer->vadj->upper))
-			g_signal_emit (G_OBJECT (viewer), 
-				       image_viewer_signals[SIZE_CHANGED], 
-				       0);
+			gth_iviewer_size_changed (GTH_IVIEWER (viewer));
 
 		/* Change adjustment values. */
 
@@ -1381,9 +1368,7 @@ image_viewer_size_allocate (GtkWidget       *widget,
 					allocation->width, allocation->height);
 
 	if (! viewer->skip_size_change)
-		g_signal_emit (G_OBJECT (viewer), 
-			       image_viewer_signals[SIZE_CHANGED], 
-			       0);
+		gth_iviewer_size_changed (GTH_IVIEWER (viewer));
 	else
 		viewer->skip_size_change = FALSE;
 }
@@ -1448,6 +1433,34 @@ image_viewer_scroll_event (GtkWidget        *widget,
 }
 
 
+void
+image_viewer_get_adjustments (GthIViewer     *self,
+			      GtkAdjustment **hadj,
+			      GtkAdjustment **vadj)
+{
+	ImageViewer *viewer = IMAGE_VIEWER (self);
+	if (hadj != NULL)
+		*hadj = viewer->hadj;
+	if (vadj != NULL)
+		*vadj = viewer->vadj;
+}
+
+
+static void
+gth_iviewer_interface_init (gpointer   g_iface,
+			    gpointer   iface_data)
+{
+	GthIViewerInterface *iface = (GthIViewerInterface *)g_iface;
+
+	iface->get_zoom = image_viewer_get_zoom;
+	iface->set_zoom = image_viewer_set_zoom;
+	iface->zoom_in = image_viewer_zoom_in;
+	iface->zoom_out = image_viewer_zoom_out;
+	iface->get_image = image_viewer_get_current_pixbuf;
+	iface->get_adjustments = image_viewer_get_adjustments;
+}
+
+
 
 
 
@@ -1468,11 +1481,19 @@ image_viewer_get_type ()
 			0,
 			(GInstanceInitFunc) image_viewer_init
 		};
+		static const GInterfaceInfo iviewer_info = {
+			(GInterfaceInitFunc) gth_iviewer_interface_init,
+			NULL,
+			NULL
+		};
 
 		type = g_type_register_static (GTK_TYPE_WIDGET,
 					       "ImageViewer",
 					       &type_info,
-					       0);
+					       0); 
+		g_type_add_interface_static (type,
+					     GTH_TYPE_IVIEWER,
+					     &iviewer_info);
 	}
 
         return type;
@@ -2422,6 +2443,17 @@ image_viewer_scroll_page_y (ImageViewer *viewer,
 }
 
 
+void
+image_viewer_get_scroll_offset  (ImageViewer *viewer,
+				 int         *x,
+				 int         *y)
+{
+	g_return_if_fail (IS_IMAGE_VIEWER (viewer));
+	*x = viewer->x_offset;
+	*y = viewer->y_offset;
+}
+
+
 void
 image_viewer_size (ImageViewer *viewer,
 		   int          width,
