@@ -26,6 +26,7 @@
 
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
+#include <libgnomevfs/gnome-vfs-utils.h>
 #include "gth-folder-selection-dialog.h"
 
 #include "bookmark-list.h"
@@ -270,7 +271,7 @@ file_sel_ok_clicked_cb (GtkDialog  *file_sel,
 
 	folder_sel = g_object_get_data (G_OBJECT (file_sel), "folder_sel");
 	
-	folder = g_strdup (gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (file_sel)));
+	folder = gtk_file_chooser_get_uri (GTK_FILE_CHOOSER (file_sel));
 	gth_folder_selection_set_folder (folder_sel, folder);
 
 	gtk_widget_destroy (GTK_WIDGET (file_sel));
@@ -306,7 +307,7 @@ browse_button_clicked_cb (GtkWidget *widget,
 		folder = tmp;
 	}
 
-	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (file_sel), folder);
+	gtk_file_chooser_set_current_folder_uri (GTK_FILE_CHOOSER (file_sel), folder);
 	g_free (folder);
 	
 	g_object_set_data (G_OBJECT (file_sel), "folder_sel", folder_sel);
@@ -585,7 +586,14 @@ gth_folder_selection_set_folder (GthFolderSelection *fsel,
 char *
 gth_folder_selection_get_folder (GthFolderSelection *fsel)
 {
-	return _gtk_entry_get_filename_text (GTK_ENTRY (fsel->priv->file_entry));
+	char *value;
+	char *retval;
+	
+	value = _gtk_entry_get_filename_text (GTK_ENTRY (fsel->priv->file_entry));
+	retval = gnome_vfs_unescape_string (value, "");
+	g_free (value);
+	
+	return retval;
 }
 
 
