@@ -690,8 +690,12 @@ viewer_update_image_info (GthViewer *viewer)
 			priv->exif_data = NULL;
 		}
 		
-		if (priv->image_path != NULL)
-			jdata = jpeg_data_new_from_file (priv->image_path);
+		if (priv->image_path != NULL) {
+			const char *path = get_file_path_from_uri (priv->image_path);
+			if (path != NULL)
+				jdata = jpeg_data_new_from_file (priv->image_path);
+		}
+
 		if (jdata != NULL) {
 			priv->exif_data = jpeg_data_get_exif_data (jdata);
 			jpeg_data_unref (jdata);
@@ -851,6 +855,10 @@ save_jpeg_data (GthViewer  *viewer,
 	gboolean               data_to_save = FALSE;
 	JPEGData              *jdata;
 
+	filename = get_file_path_from_uri (filename);
+	if (filename == NULL)
+		return;
+
 	if (priv->exif_data != NULL) 
 		data_to_save = TRUE;
 	
@@ -914,7 +922,7 @@ save_pixbuf__image_saved_cb (const char *filename,
 	if (priv->closing)
 		return;
 
-	if (strcmp (priv->image_path, filename) != 0) {
+	if (! same_uri (priv->image_path, filename)) {
 		/*FIXME: gtk_widget_show (gth_viewer_new (filename));*/
 		gth_viewer_load (viewer, filename);
 
@@ -1393,7 +1401,7 @@ monitor_update_files_cb (GthMonitor      *monitor,
 
 	if (g_list_find_custom (list, 
 				viewer->priv->image_path, 
-				(GCompareFunc) strcmp) == NULL)
+				(GCompareFunc) uricmp) == NULL)
 		return;
 
 	switch (event) {
@@ -1422,7 +1430,7 @@ monitor_file_renamed_cb (GthMonitor *monitor,
 	if (viewer->priv->image_path == NULL)
 		return;
 
-	if (strcmp (old_name, viewer->priv->image_path) != 0)
+	if (! same_uri (old_name, viewer->priv->image_path))
 		return;
 
 	g_free (viewer->priv->image_path);
@@ -2454,20 +2462,20 @@ gth_viewer_get_type ()
 }
 
 
-void
-compute_single_viewer_window (void)
+GtkWidget *
+gth_viewer_get_current_viewer (void)
 {
 	GList *windows = gth_window_get_window_list ();
 	GList *scan;
 		
-	if (SingleViewer != NULL) 
-		return;
-
-	for (scan = windows; scan; scan = scan->next) {
-		GthWindow *window = scan->data;
-		if (GTH_IS_VIEWER (window)) {
-			SingleViewer = (GthViewer*) window;
-			break;
+	if (SingleViewer == NULL) 
+		for (scan = windows; scan; scan = scan->next) {
+			GthWindow *window = scan->data;
+			if (GTH_IS_VIEWER (window)) {
+				SingleViewer = (GthViewer*) window;
+				break;
+			}
 		}
-	}
+
+	return (GtkWidget*) SingleViewer;
 }
